%bcond_with gtk2

%global builddirsfirmw {hdsploader mixartloader usx2yloader vxloader }
%global _pkgdocdir %{_docdir}/%{name}-%{version}

%if %{with gtk2}
%global builddirstools {as10k1 echomixer envy24control hdspconf hdspmixer hwmixvolume rmedigicontrol sbiload sb16_csp sscape_ctl us428control hda-verb hdajackretask hdajacksensetest }
%else
%global builddirstools {as10k1 hdspconf hdspmixer hwmixvolume sbiload sb16_csp sscape_ctl us428control hda-verb hdajackretask hdajacksensetest}
%endif

Summary:        Specialist tools for ALSA
Name:           alsa-tools
Version:        1.2.5
Release:        6%{?dist}
License:        GPLv2+
URL:            http://www.alsa-project.org/
Source0:        ftp://ftp.alsa-project.org/pub/tools/%{name}-%{version}.tar.bz2
Source1:        90-alsa-tools-firmware.rules
Patch3000:      hwmixvolume-python.patch
Patch5000:      fix-coredump-in-hdspmixer.patch

BuildRequires:  gcc gcc-c++ make
BuildRequires:  alsa-lib-devel >= %{version} fltk-devel
BuildRequires:  gtk3-devel  
Buildrequires:  desktop-file-utils yum dnf
%if %{with gtk2}
BuildRequires:  gtk2-devel
%endif
Requires:       xorg-x11-fonts-misc  python3-alsa

%description
This package contains several specialist tools for use with ALSA, including
a number of programs that provide access to special hardware facilities on
certain sound cards.

* as10k1 - AS10k1 Assembler
* cspctl - Sound Blaster 16 ASP/CSP control program
* echomixer - Mixer for Echo Audio (indigo) devices
* envy24control - Control tool for Envy24 (ice1712) based soundcards
* hdspmixer - Mixer for the RME Hammerfall DSP cards
* hwmixvolume - Control the volume of individual streams on sound cards that
  use hardware mixing
* rmedigicontrol - Control panel for RME Hammerfall cards
* sbiload - An OPL2/3 FM instrument loader for ALSA sequencer
* sscape_ctl - ALSA SoundScape control utility
* us428control - Control tool for Tascam 428
* hda-verb - Direct HDA codec access
* hdajackretask - Reassign the I/O jacks on the HDA hardware
* hdajacksensetest - The sense test for the I/O jacks on the HDA hardware


%package firmware
Summary:        ALSA tools for uploading firmware to some soundcards
Requires:       udev alsa-firmware fxload


%description firmware
This package contains tools for flashing firmware into certain sound cards.
The following tools are available:

* hdsploader   - for RME Hammerfall DSP cards
* mixartloader - for Digigram miXart soundcards
* vxloader     - for Digigram VX soundcards
* usx2yloader  - second phase firmware loader for Tascam USX2Y USB soundcards

%prep
%autosetup -p1 -n %{name}-%{version}

%build
mv seq/sbiload . ; rm -rf seq

for i in %{builddirstools} %{builddirsfirmw}
do
  cd $i ;%configure
  %make_build || exit 1
  cd ..
done

%install
mkdir -p %{buildroot}%{_datadir}/{pixmaps,applications}

for i in %{builddirstools} %{builddirsfirmw}
do
  case $i in
    usx2yloader)
      (cd $i ; %make_install hotplugdir=/lib/udev) || exit 1
      ;;
    *)
      (cd $i ; %make_install) || exit 1
      ;;
   esac
   if [[ -s "${i}"/README ]]
   then
      if [[ ! -d "%{buildroot}%{_pkgdocdir}/${i}" ]]
      then
         mkdir -p "%{buildroot}%{_pkgdocdir}/${i}"
      fi
      cp "${i}"/README "%{buildroot}%{_pkgdocdir}/${i}"
   fi
   if [[ -s "${i}"/COPYING ]]
   then
      if [[ ! -d "%{buildroot}%{_pkgdocdir}/${i}" ]]
      then
         mkdir -p "%{buildroot}%{_pkgdocdir}/${i}"
      fi
      cp "${i}"/COPYING "%{buildroot}%{_pkgdocdir}/${i}"
   fi
   if [[ -s %{buildroot}%{_datadir}/applications/${i}.desktop ]] ; then
      desktop-file-validate %{buildroot}%{_datadir}/applications/${i}.desktop
      desktop-file-install --dir %{buildroot}%{_datadir}/applications \
        %{buildroot}%{_datadir}/applications/${i}.desktop
   fi
done

rm -f %{buildroot}/lib/udev/tascam_fw.usermap
mkdir -p %{buildroot}/lib/udev/rules.d
install -m 644 %{SOURCE1} %{buildroot}/lib/udev/rules.d

%files
%license as10k1/COPYING hdspconf/COPYING hdspmixer/COPYING sb16_csp/COPYING
%dir %{_pkgdocdir}
%doc %{_pkgdocdir}/as10k1
%doc %{_pkgdocdir}/hdspconf
%doc %{_pkgdocdir}/hdspmixer
%doc %{_pkgdocdir}/hwmixvolume
%doc %{_pkgdocdir}/sbiload
%doc %{_pkgdocdir}/hda-verb
%doc %{_pkgdocdir}/hdajackretask
%doc %{_pkgdocdir}/sb16_csp
%if %{with gtk2}
%license echomixer/COPYING envy24control/COPYING rmedigicontrol/COPYING
%doc %{_pkgdocdir}/echomixer
%doc %{_pkgdocdir}/envy24control
%doc %{_pkgdocdir}/rmedigicontrol
%{_bindir}/echomixer
%{_bindir}/envy24control
%{_bindir}/rmedigicontrol
%endif
%{_bindir}/as10k1
%{_bindir}/hdspconf
%{_bindir}/hdspmixer
%{_bindir}/hwmixvolume
%{_bindir}/sbiload
%{_bindir}/sscape_ctl
%{_bindir}/us428control
%{_bindir}/hda-verb
%{_bindir}/hdajackretask
%{_bindir}/hdajacksensetest
%{_bindir}/cspctl
%{_datadir}/sounds/*
%{_datadir}/applications/*.desktop
%{_datadir}/icons/hicolor/*/apps*
%{_datadir}/man/man1/cspctl.1.gz



%files firmware
%license hdsploader/COPYING
%dir %{_pkgdocdir}
%doc %{_pkgdocdir}/hdsploader
%doc %{_pkgdocdir}/mixartloader
%doc %{_pkgdocdir}/usx2yloader
%doc %{_pkgdocdir}/vxloader
/lib/udev/rules.d/*.rules
/lib/udev/tascam_fpga
/lib/udev/tascam_fw
%{_bindir}/hdsploader
%{_bindir}/mixartloader
%{_bindir}/usx2yloader
%{_bindir}/vxloader


%changelog
* Fri Aug 16 2024 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 1.2.5-6
- Rebuilt for loongarch release

* Fri Sep 08 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 1.2.5-5
- Rebuilt for OpenCloudOS Stream 23.09

* Fri Apr 28 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 1.2.5-4
- Rebuilt for OpenCloudOS Stream 23.05

* Fri Mar 31 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 1.2.5-3
- Rebuilt for OpenCloudOS Stream 23

* Mon Nov 28 2022 Feng Weiyao <wynnfeng@tencent.com> - 1.2.5-2
- fix core dumped in hdspmixer.cxx.

* Mon Nov 28 2022 Feng Weiyao <wynnfeng@tencent.com> - 1.2.5-1
- package init.
